import ec2 = require('@aws-cdk/aws-ec2');
import cdk = require('@aws-cdk/cdk');
import { BaseService, BaseServiceProps } from '../base/base-service';
import { TaskDefinition } from '../base/task-definition';
import { ICluster } from '../cluster';
/**
 * Properties to define a Fargate service
 */
export interface FargateServiceProps extends BaseServiceProps {
    /**
     * Cluster where service will be deployed
     */
    readonly cluster: ICluster;
    /**
     * Task Definition used for running tasks in the service
     */
    readonly taskDefinition: TaskDefinition;
    /**
     * Assign public IP addresses to each task
     *
     * @default false
     */
    readonly assignPublicIp?: boolean;
    /**
     * In what subnets to place the task's ENIs
     *
     * @default Private subnet if assignPublicIp, public subnets otherwise
     */
    readonly vpcSubnets?: ec2.SubnetSelection;
    /**
     * Existing security group to use for the tasks
     *
     * @default A new security group is created
     */
    readonly securityGroup?: ec2.ISecurityGroup;
    /**
     * Fargate platform version to run this service on
     *
     * Unless you have specific compatibility requirements, you don't need to
     * specify this.
     *
     * @default Latest
     */
    readonly platformVersion?: FargatePlatformVersion;
}
/**
 * Start a service on an ECS cluster
 */
export declare class FargateService extends BaseService {
    constructor(scope: cdk.Construct, id: string, props: FargateServiceProps);
}
/**
 * Fargate platform version
 *
 * @see https://docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html
 */
export declare enum FargatePlatformVersion {
    /**
     * The latest, recommended platform version
     */
    Latest = "LATEST",
    /**
     * Version 1.3.0
     *
     * Supports secrets, task recycling.
     */
    Version1_3 = "1.3.0",
    /**
     * Version 1.2.0
     *
     * Supports private registries.
     */
    Version1_2 = "1.2.0",
    /**
     * Version 1.1.0
     *
     * Supports task metadata, health checks, service discovery.
     */
    Version1_1 = "1.1.0",
    /**
     * Initial release
     *
     * Based on Amazon Linux 2017.09.
     */
    Version1_0 = "1.0.0"
}
